/*
 *
 * Copyright(C) OASIS(R) 2009, 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.
 *
 */

/**
 * C++ component implementation with
 * 1 service with interface Service1,
 * 1 reference (1..1) with interface Service1
 * - reference gets called when service1 operation1 is invoked
 * - implementation test whether the mutable parameter of Service4 operation1 gets modified by the target service
 * @author Bryan Aupperle
 *
 */

#include "Service1Impl7.h"
#include "oasis/sca/RefCountingPointer.h"
#include "oasis/sca/ComponentContext.h"
#include "commonj/sdo/sdo.h"
#include <string>
#include <list>
using namespace oasis::sca;

// Construction/Destruction

Service1Impl7::Service1Impl7()
{
	ComponentContextPtr context = ComponentContext::getCurrent();

	commonj::sdo::DataObjectPtr properties = context->getProperties();

	serviceName = properties->getString("serviceName");

	return;
}


Service1Impl7::~Service1Impl7()
{
	return;
}

// Implementation

std::string Service1Impl7::operation1(const std::string input) {
	std::string result;
	std::list<std::string> parameter;

	ComponentContextPtr context = ComponentContext::getCurrent();

	ServiceProxyPtr service = context->getService("reference1");
	reference1 = dynamicCast<Service4Proxy>(service);

	if (reference1) {
		parameter.push_front(input);
	    parameter.push_back("Second");
		result = reference1->operation1(parameter);
		std::list<std::string>::iterator it = parameter.begin();
		if (input != *it)
			return serviceName + "input parameter modified!!";
	}

	return serviceName + " operation1 invoked" + " " + result;
}
